from moontour_common.models.guess import Guess
from moontour_common.models.phase import HealthPhase
from moontour_common.models.rooms.room import BaseRoom

START_HEALTH = 5000


class HealthRoom(BaseRoom):
    start_health = START_HEALTH
    guess_duration: float = 15  # Time between first guess to phase ending
    phases: list[HealthPhase] = []
    guesses: list[dict[str, Guess]] = []  # User ID to guess



from datetime import datetime

from pydantic import BaseModel, Field

from moontour_common.models import Coordinates
import geopy.distance


MAX_POINTS = 5000


class Guess(BaseModel):
    time: datetime = Field(default_factory=datetime.now)
    coordinates: Coordinates

    def get_points(self, target: Coordinates) -> int:
        distance = geopy.distance.geodesic(
            (target.latitude, target.longitude),
            (self.coordinates.latitude, self.coordinates.longitude)
        ).km
        return max(MAX_POINTS - int(distance), 0)
